@@ -1,5 +1,5 @@
 from .file_utils import findGlobFiles
-from ..file_filtering.file_filters import get_files_and_dirs
+from ..file_filtering.file_filters import get_files_and_dirs,define_defaults
 from ..file_handlers.file_readers import read_any_file
 from abstract_utilities import make_list
 import os,re
@@ -62,13 +62,16 @@ def find_lines(content, strings, total_strings=False, normalize=True, any_per_li
     return hits
 def getPaths(files, strings):
     tot_strings = strings
+    nu_files, found_paths = [], []
     if isinstance(strings,list):
         if len(strings) >1:
             tot_strings = '\n'.join(strings)
         else:
+            if len(strings) == 0:
+                return nu_files, found_paths
             tot_strings = strings[0]
     
-    nu_files, found_paths = [], []
+    
     for file_path in files:
         try:
             og_content = read_any_file(file_path)
@@ -91,6 +94,7 @@ def getPaths(files, strings):
 
 def findContent(
     directory: str,
+    cfg: Optional["ScanConfig"] = None,
     allowed_exts: Optional[Set[str]] = False,
     unallowed_exts: Optional[Set[str]] = False,
     exclude_types: Optional[Set[str]] = False,
@@ -103,17 +107,21 @@ def findContent(
     parse_lines=False,
     spec_line=False,
     get_lines=True,
-    diffs=False
+    diffs=False,
+    **kwargs
 ):
-    found_paths = []
-    dirs,files = get_files_and_dirs(
-        directory=directory,
+    cfg = cfg or define_defaults(
         allowed_exts=allowed_exts,
         unallowed_exts=unallowed_exts,
         exclude_types=exclude_types,
         exclude_dirs=exclude_dirs,
         exclude_patterns=exclude_patterns,
-        add=add,
+        add=add
+        )
+    found_paths = []
+    dirs,files = get_files_and_dirs(
+        directory=directory,
+        cfg=cfg,
         recursive=recursive
         )
     nu_files,found_paths = getPaths(files,strings)
@@ -178,6 +186,7 @@ def editLines(file_paths):
         get_edit(file_path)
 def findContentAndEdit(
     directory: str,
+    cfg: Optional["ScanConfig"] = None,
     allowed_exts: Optional[Set[str]] = False,
     unallowed_exts: Optional[Set[str]] = False,
     exclude_types: Optional[Set[str]] = False,
@@ -191,18 +200,21 @@ def findContentAndEdit(
     spec_line=False,
     get_lines=True,
     edit_lines=False,
-    diffs=False
+    diffs=False,
+    **kwargs
     ):
 
-
+    cfg = cfg or define_defaults(
+        allowed_exts=allowed_exts,
+        unallowed_exts=unallowed_exts,
+        exclude_types=exclude_types,
+        exclude_dirs=exclude_dirs,
+        exclude_patterns=exclude_patterns,
+        add=add
+        )
     file_paths = findContent(
             directory=directory,
-            allowed_exts=allowed_exts,
-            unallowed_exts= unallowed_exts,
-            exclude_types= exclude_types,
-            exclude_dirs= exclude_dirs,
-            exclude_patterns = exclude_patterns,
-            add = add,
+            cfg=cfg,
             recursive= recursive,
             strings=strings,
             total_strings=total_strings,
